@@ -1,4 +1,4 @@
-/* $Id: gweather-pref.c,v 1.79 2004/06/20 20:56:14 dsmit Exp $ */
+/* $Id: gweather-pref.c,v 1.80 2004/07/26 00:04:47 gowen Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -411,13 +411,14 @@ static void parse_temp_string (const gchar *gconf_str, GWeatherPrefs *prefs)
         }
     }
     if (!prefs->temperature_unit || prefs->temperature_unit == TEMP_UNIT_DEFAULT ) {
+#ifdef _NL_MEASUREMENT_MEASUREMENT
         imperial = nl_langinfo(_NL_MEASUREMENT_MEASUREMENT);
         if ( imperial && imperial[0] == 2 )  {
             /* imperial */
             prefs->temperature_unit = TEMP_UNIT_FAHRENHEIT;
-        } else {
+        } else
+#endif
             prefs->temperature_unit = TEMP_UNIT_CENTIGRADE;
-        }
     }
 }
 
@@ -446,13 +447,14 @@ static void parse_speed_string (const gchar *gconf_str, GWeatherPrefs *prefs)
         }
     }
     if ( (!prefs->speed_unit) || prefs->speed_unit == SPEED_UNIT_DEFAULT ) {
+#ifdef _NL_MEASUREMENT_MEASUREMENT
         imperial = nl_langinfo(_NL_MEASUREMENT_MEASUREMENT);
         if ( imperial && imperial[0] == 2 )  {
             /* imperial */
             prefs->speed_unit = SPEED_UNIT_KNOTS;
-        } else {
+        } else
+#endif
             prefs->speed_unit = SPEED_UNIT_MS;
-        }
     }
 }
 
@@ -483,13 +485,14 @@ static void parse_pressure_string (const gchar *gconf_str, GWeatherPrefs *prefs)
         }
     }
     if ( (!prefs->pressure_unit) || prefs->pressure_unit == PRESSURE_UNIT_DEFAULT ) {
+#ifdef _NL_MEASUREMENT_MEASUREMENT
         imperial = nl_langinfo(_NL_MEASUREMENT_MEASUREMENT);
         if ( imperial && imperial[0] == 2 )  {
             /* imperial */
             prefs->pressure_unit = PRESSURE_UNIT_INCH_HG;
-        } else {
+        } else
+#endif
             prefs->pressure_unit = PRESSURE_UNIT_HPA;
-        }
     }	
 }
 
@@ -518,13 +521,14 @@ static void parse_distance_string (const gchar *gconf_str, GWeatherPrefs *prefs)
     }
 
 	if ((!prefs->distance_unit) || prefs->distance_unit == DISTANCE_UNIT_DEFAULT ) {
+#ifdef _NL_MEASUREMENT_MEASUREMENT
         imperial = nl_langinfo(_NL_MEASUREMENT_MEASUREMENT);
         if ( imperial && imperial[0] == 2 )  {
             /* imperial */
             prefs->distance_unit = DISTANCE_UNIT_MILES;
-        } else {
+        } else
+#endif
             prefs->distance_unit = DISTANCE_UNIT_METERS;
-        }
     }
 
     return;
